@@ -1,7 +1,7 @@
 package POEx::ZMQ::Socket;
-$POEx::ZMQ::Socket::VERSION = '0.005005';
+$POEx::ZMQ::Socket::VERSION = '0.005006';
 use v5.10;
-use strictures 1;
+use strictures 2;
 
 use Carp;
 use Scalar::Util 'reftype';
@@ -288,7 +288,7 @@ sub send_multipart {
   my ($self, $parts, $flags) = @_;
 
   confess "Expected an ARRAY of message parts"
-    unless reftype $parts eq 'ARRAY' and @$parts;
+    unless ref $parts and reftype $parts eq 'ARRAY' and @$parts;
 
   return if $self->_message_not_sendable($parts, $flags, 'IS_MULTIPART');
 
